Point class

A 2D point in image/pixel space.

Constructors

Point(double x, double y)
Point.fromMap(Map map)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
x double
final
y double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, double>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited