YOLODepthMap class

Dense row-major metric depth output.

Constructors

YOLODepthMap({required Float32List values, required int width, required int height, required double minDepth, required double maxDepth})
YOLODepthMap.fromMap(Map map)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
height int
final
maxDepth double
final
minDepth double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
values Float32List
Distance in meters for every map pixel.
final
width int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited