MiniZip class

A small ZIP extractor for standard PKZIP archives.

It supports the STORED and raw-DEFLATE methods used by Core ML .mlpackage.zip model archives. Unsupported features are rejected rather than silently mis-extracted.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

extractBytes(List<int> bytes, {required Directory destination, String? stripTopLevelDirectoryEndingWith, bool skip(String path)?}) → void
Extracts bytes into destination.