YOLODetectionResults class
Complete output from a YOLO inference: detections, optional annotated image, and processing time in milliseconds.
Constructors
-
YOLODetectionResults({required List<
YOLOResult> detections, Uint8List? annotatedImage, required double processingTimeMs}) - YOLODetectionResults.fromMap(Map map)
-
Creates YOLODetectionResults from a map representation.
factory
Properties
- annotatedImage → Uint8List?
-
The original image with detection visualizations overlaid.
final
-
detections
→ List<
YOLOResult> -
List of all objects detected in the image.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- processingTimeMs → double
-
The time taken to process the image in milliseconds.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited