showSemanticTask property
When false, the Semantic segment is hidden for hosts that do not want to expose semantic segmentation.
Implementation
final bool showSemanticTask;
When false, the Semantic segment is hidden for hosts that do not want to expose semantic segmentation.
final bool showSemanticTask;