sliderWidthFactor property
Fraction of the available width the slider track occupies (iOS sliderWidth = width * 0.46). The caption above
always spans full width so it never wraps.
Implementation
final double sliderWidthFactor;
Fraction of the available width the slider track occupies (iOS sliderWidth = width * 0.46). The caption above
always spans full width so it never wraps.
final double sliderWidthFactor;