LensInfo class
Describes a discoverable camera lens (e.g. ultra-wide, wide, telephoto).
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- label → String
-
Human-readable label such as
Ultra wide cameraorTelephoto camera.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- zoomFactor → double
-
Zoom factor used to engage this lens (e.g.
0.5,1.0,2.0).final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited