YOLOViewController class

Controls a YOLOView imperatively: thresholds, camera, zoom, streaming.

Constructors

YOLOViewController()

Properties

confidenceThreshold double
no setter
hashCode int
The hash code for this object.
no setterinherited
iouThreshold double
no setter
isInitialized bool
no setter
numItemsThreshold int
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

captureFrame() Future<Uint8List?>
init(MethodChannel methodChannel, int viewId) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
restartCamera() Future<void>
setConfidenceThreshold(double threshold) Future<void>
setIoUThreshold(double threshold) Future<void>
setNumItemsThreshold(int numItems) Future<void>
setShowOverlays(bool show) Future<void>
setShowUIControls(bool show) Future<void>
setStreamingConfig(YOLOStreamingConfig config) Future<void>
setThresholds({double? confidenceThreshold, double? iouThreshold, int? numItemsThreshold}) Future<void>
setTorchMode(bool enabled) Future<void>
setZoomLevel(double zoomLevel) Future<void>
stop() Future<void>
switchCamera() Future<void>
switchModel(String modelPath, [YOLOTask? task]) Future<void>
toString() String
A string representation of this object.
inherited
zoomIn() Future<void>
zoomOut() Future<void>

Operators

operator ==(Object other) bool
The equality operator.
inherited