YOLOView class
A Flutter widget that displays a real-time camera preview with YOLO object detection.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- YOLOView
Constructors
-
YOLOView({Key? key, required String modelPath, YOLOTask? task, YOLOViewController? controller, String cameraResolution = '720p', dynamic onResult(List<
YOLOResult> )?, dynamic onPerformanceMetrics(YOLOPerformanceMetrics)?, dynamic onStreamingData(Map<String, dynamic> )?, bool showNativeUI = false, dynamic onZoomChanged(double zoomLevel)?, YOLOStreamingConfig? streamingConfig, double confidenceThreshold = 0.25, double iouThreshold = 0.7, bool useGpu = true, bool showOverlays = true, YOLOOverlayTheme overlayTheme = const YOLOOverlayTheme(), LensFacing lensFacing = LensFacing.back}) -
const
Properties
- cameraResolution → String
-
final
- confidenceThreshold → double
-
final
- controller → YOLOViewController?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- iouThreshold → double
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- lensFacing → LensFacing
-
final
- modelPath → String
-
final
- onPerformanceMetrics → dynamic Function(YOLOPerformanceMetrics)?
-
final
-
onResult
→ dynamic Function(List<
YOLOResult> )? -
final
-
onStreamingData
→ dynamic Function(Map<
String, dynamic> )? -
final
- onZoomChanged → dynamic Function(double zoomLevel)?
-
final
- overlayTheme → YOLOOverlayTheme
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showNativeUI → bool
-
final
- showOverlays → bool
-
final
- streamingConfig → YOLOStreamingConfig?
-
final
- task → YOLOTask?
-
final
- useGpu → bool
-
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< YOLOView> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited